@@ -8,16 +8,19 @@ get_predictions_glimML <- function(model, fitfram, ci.lvl, linv, ...) {
   else
     ci <- 0.975
 
+  # degrees of freedom
+  dof <- .get_df(model)
+  tcrit <- stats::qt(ci, df = dof)
+
   insight::check_if_installed("aod")
 
-  prdat <-
-    aod::predict(
-      model,
-      newdata = fitfram,
-      type = "link",
-      se.fit = se,
-      ...
-    )
+  prdat <- aod::predict(
+    model,
+    newdata = fitfram,
+    type = "link",
+    se.fit = se,
+    ...
+  )
 
   # copy predictions
   fitfram$predicted <- linv(prdat$fit)
@@ -25,8 +28,8 @@ get_predictions_glimML <- function(model, fitfram, ci.lvl, linv, ...) {
   # did user request standard errors? if yes, compute CI
   if (se) {
     # calculate CI
-    fitfram$conf.low <- linv(prdat$fit - stats::qnorm(ci) * prdat$se.fit)
-    fitfram$conf.high <- linv(prdat$fit + stats::qnorm(ci) * prdat$se.fit)
+    fitfram$conf.low <- linv(prdat$fit - tcrit * prdat$se.fit)
+    fitfram$conf.high <- linv(prdat$fit + tcrit * prdat$se.fit)
 
     # copy standard errors
     attr(fitfram, "std.error") <- prdat$se.fit
