@@ -175,7 +175,7 @@ get_predictions_glmmTMB <- function(model,
     if (isTRUE(model$modelInfo$REML) && !type %in% c("re", "re.zi") && !identical(interval, "confidence") && verbose) {
       insight::format_alert(
         "Model was fit with `REML = TRUE`. Don't be surprised when standard errors and confidence intervals from `predict()` are different.", # nolint
-        "To match results from `ggpredict()` from those with `predict()`, use `type = \"random\"` and `interval = \"confidence\"`, or refit the model with `REML = FALSE`." # nolint
+        "To match results from `predict_response()` with those from `predict()`, use `type = \"random\"` and `interval = \"confidence\"`, or refit the model with `REML = FALSE`." # nolint
       )
     }
 
