@@ -14,21 +14,19 @@
   interval = NULL) {
 
   se <- tryCatch(
-    {
-      .safe_se_from_vcov(
-        model,
-        prediction_data,
-        value_adjustment,
-        terms,
-        model_class,
-        type,
-        vcov.fun,
-        vcov.type,
-        vcov.args,
-        condition,
-        interval
-      )
-    },
+    .safe_se_from_vcov(
+      model,
+      prediction_data,
+      value_adjustment,
+      terms,
+      model_class,
+      type,
+      vcov.fun,
+      vcov.type,
+      vcov.args,
+      condition,
+      interval
+    ),
     error = function(x) x,
     warning = function(x) NULL,
     finally = function(x) NULL
@@ -96,22 +94,10 @@
     value_adjustment = value_adjustment,
     factor_adjustment = FALSE,
     show_pretty_message = FALSE,
-    condition = condition
+    condition = condition,
+    verbose = FALSE
   )
 
-  # make sure we have enough values to compute CI
-  # nlevels_terms <- sapply(
-  #   colnames(newdata),
-  #   function(.x) !(.x %in% re.terms) && is.factor(newdata[[.x]]) && nlevels(newdata[[.x]]) == 1
-  # )
-
-  # if (any(nlevels_terms)) {
-  #   not_enough <- colnames(newdata)[which(nlevels_terms)[1]]
-  #   remove_lvl <- paste0("[", gsub(pattern = "(.*)\\[(.*)\\]", replacement = "\\2", x = terms[which(.clean_terms(terms) == not_enough)]), "]", collapse = "")
-  #   stop(sprintf("`%s` does not have enough factor levels. Try to remove `%s`.", not_enough, remove_lvl), call. = TRUE)
-  # }
-
-
   # add response to newdata. For models fitted with "glmmPQL",
   # the response variable is renamed internally to "zz".
 
@@ -120,7 +106,7 @@
     names(new.resp) <- "zz"
   } else {
     fr <- insight::find_response(model, combine = FALSE)
-    new.resp <- rep(0, length.out = length(fr))
+    new.resp <- rep_len(0, length(fr))
     names(new.resp) <- fr
   }
 
